This module is used when you have run $N$ trajectories each of which was computed by integrating a different biased Hamiltonian.  The binless WHAM that is implemented in 
this modules actions can be used to extract the probability of observing the set of configurations during the $N$ trajectories. You can then use this information to construct 
the distribution that would have been observed in an unbiased simulation.

